@@ -54,7 +54,7 @@ library(contextual)
 #
 # ------------------------------------------------------------------------------------------------------------
 
-horizon                           <- 10000L
+horizon                           <- 8000L
 simulations                       <- 1L
 
 # Bandit representing Male and Female actual preferences for sports and movies.
@@ -85,8 +85,8 @@ u_dt                              <- history$get_data_table()
 
 print("1a. Unbiased data generation.")
 
-print(paste("Sport:",sum(u_dt[choice==1]$reward)/nrow(u_dt[choice==1]))) # 0.6 CTR Sport - correct.
-print(paste("Movie:",sum(u_dt[choice==2]$reward)/nrow(u_dt[choice==2]))) # 0.5 CTR Movie - correct.
+print(paste("Sport:",round(sum(u_dt[choice==1]$reward)/nrow(u_dt[choice==1]),1))) # 0.6 CTR Sport - correct.
+print(paste("Movie:",round(sum(u_dt[choice==2]$reward)/nrow(u_dt[choice==2]),1))) # 0.5 CTR Movie - correct.
 
 # ----------------------------------   Use unbiased as offline data    ---------------------------------------
 
@@ -105,8 +105,8 @@ ru_dt                             <- history$get_data_table()
 
 print("1b. Offline unbiased policy evaluation.")
 
-print(paste("Sport:",sum(ru_dt[choice==1]$reward)/nrow(ru_dt[choice==1]))) # 0.6 CTR Sport - correct.
-print(paste("Movie:",sum(ru_dt[choice==2]$reward)/nrow(ru_dt[choice==2]))) # 0.5 CTR Movie - correct.
+print(paste("Sport:",round(sum(ru_dt[choice==1]$reward)/nrow(ru_dt[choice==1]),1))) # 0.6 CTR Sport - correct.
+print(paste("Movie:",round(sum(ru_dt[choice==2]$reward)/nrow(ru_dt[choice==2]),1))) # 0.5 CTR Movie - correct.
 
 # ------------------------------------------------------------------------------------------------------------
 # ----------------------------------   Biased policy       ---------------------------------------------------
@@ -155,8 +155,8 @@ b_dt                              <- history$get_data_table()
 
 print("2a. Biased data generation.")
 
-print(paste("Sport:",sum(b_dt[choice==1]$reward)/nrow(b_dt[choice==1]))) # 0.5 CTR Sport - Simpson's..
-print(paste("Movie:",sum(b_dt[choice==2]$reward)/nrow(b_dt[choice==2]))) # 0.6 CTR Movie - Simpson's..
+print(paste("Sport:",round(sum(b_dt[choice==1]$reward)/nrow(b_dt[choice==1]),1))) # 0.5 CTR Sport, Simpson's..
+print(paste("Movie:",round(sum(b_dt[choice==2]$reward)/nrow(b_dt[choice==2]),1))) # 0.6 CTR Movie, Simpson's..
 
 # ----------------------------------   Use biased as offline data    -----------------------------------------
 
@@ -177,8 +177,8 @@ rb_dt                             <- history$get_data_table()
 
 print("2b. Offline biased policy evaluation.")
 
-print(paste("Sport:",sum(rb_dt[choice==1]$reward)/nrow(rb_dt[choice==1]))) # 0.5 CTR Sport - Simpson's..
-print(paste("Movie:",sum(rb_dt[choice==2]$reward)/nrow(rb_dt[choice==2]))) # 0.6 CTR Movie - Simpson's..
+print(paste("Sport:",round(sum(rb_dt[choice==1]$reward)/nrow(rb_dt[choice==1]),1))) # 0.5 CTR Sport, Simpson's
+print(paste("Movie:",round(sum(rb_dt[choice==2]$reward)/nrow(rb_dt[choice==2]),1))) # 0.6 CTR Movie, Simpson's
 
 # ------------------------------------------------------------------------------------------------------------
 # ----------------------------------   Biased policy repaired with prop      ---------------------------------
@@ -199,40 +199,40 @@ prop_dt                           <- history$get_data_table()
 
 print("2c. Offline biased policy evaluation, inverse propensity scores.")
 
-print(paste("Sport:",sum(prop_dt[choice==1]$reward)/nrow(prop_dt[choice==1]))) # 0.6 CTR Sport again, yay!
-print(paste("Movie:",sum(prop_dt[choice==2]$reward)/nrow(prop_dt[choice==2]))) # 0.5 CTR Movie again, yay!
+print(paste("Sport:",round(sum(prop_dt[choice==1]$reward)/nrow(prop_dt[choice==1]),1))) # 0.6 CTR Sport again!
+print(paste("Movie:",round(sum(prop_dt[choice==2]$reward)/nrow(prop_dt[choice==2]),1))) # 0.5 CTR Movie again!
 
 
 # ------------------------------------------------------------------------------------------------------------
 # ----------------------------------   Biased policy repaired with estimated prop  ---------------------------
 # ------------------------------------------------------------------------------------------------------------
 
-if(!require(twang)) install.packages("twang")
-
-b_dt$choice                       <- b_dt$choice - 1
-ip                                <- ps(choice ~ X.1 + X.2, data = as.data.frame(b_dt), n.trees = 2000,
-                                        stop.method = "es.mean", verbose=FALSE)
-b_dt$choice                       <- b_dt$choice + 1
-
-weights                           <- get.weights(ip, stop.method = "es.mean")  # already inverted
-b_dt$p                            <- weights
-
-f                                 <- formula("reward ~ choice | X.1 + X.2 | p")
-
-bandit                            <- OfflinePropensityWeightingBandit$new(formula = f, data = b_dt,
-                                                                          k = 2 , d = 2, inverted = TRUE)
-policy                            <- EpsilonGreedyPolicy$new(0.1)
-agent                             <- Agent$new(policy, bandit, "prop")
-
-simulation                        <- Simulator$new(agent, horizon, simulations, do_parallel = FALSE)
-history                           <- simulation$run()
-prop_dt                           <- history$get_data_table()
-
-# When no saved propensity scores, estimated propensity scores can also help remove bias:
-
-print("2c. Offline biased policy evaluation, inverse propensity scores.")
-
-print(paste("Sport:",sum(prop_dt[choice==1]$reward)/nrow(prop_dt[choice==1]))) # 0.6 CTR Sport again, yay!
-print(paste("Movie:",sum(prop_dt[choice==2]$reward)/nrow(prop_dt[choice==2]))) # 0.5 CTR Movie again, yay!
+# if(!require(twang)) install.packages("twang")
+#
+# b_dt$choice                       <- b_dt$choice - 1
+# ip                                <- ps(choice ~ X.1 + X.2, data = as.data.frame(b_dt), n.trees = 2000,
+#                                         stop.method = "es.mean", verbose=FALSE)
+# b_dt$choice                       <- b_dt$choice + 1
+#
+# weights                           <- get.weights(ip, stop.method = "es.mean")  # already inverted
+# b_dt$p                            <- weights
+#
+# f                                 <- formula("reward ~ choice | X.1 + X.2 | p")
+#
+# bandit                            <- OfflinePropensityWeightingBandit$new(formula = f, data = b_dt,
+#                                                                           k = 2 , d = 2, inverted = TRUE)
+# policy                            <- EpsilonGreedyPolicy$new(0.1)
+# agent                             <- Agent$new(policy, bandit, "prop")
+#
+# simulation                        <- Simulator$new(agent, horizon, simulations, do_parallel = FALSE)
+# history                           <- simulation$run()
+# prop_dt                           <- history$get_data_table()
+#
+# # When no saved propensity scores, estimated propensity scores can also help remove bias:
+#
+# print("2c. Offline biased policy evaluation, inverse propensity scores.")
+#
+# print(paste("Sport:",sum(prop_dt[choice==1]$reward)/nrow(prop_dt[choice==1]))) # 0.6 CTR Sport again, yay!
+# print(paste("Movie:",sum(prop_dt[choice==2]$reward)/nrow(prop_dt[choice==2]))) # 0.5 CTR Movie again, yay!
 
 
