@@ -8,25 +8,20 @@ OnlineOfflineContinuumBandit <- R6::R6Class(
   public = list(
     class_name = "OnlineOfflineContinuumBandit",
     delta = NULL,
-    c1 = NULL,
-    c2 = NULL,
-    arm_function = NULL,
+    horizon = NULL,
     choice = NULL,
-    initialize   = function(delta, horizon) {
-      self$c1 <- runif(1,0.25,0.75)
-      self$c2 <- runif(1,0.25,0.75)
-      self$arm_function <- function(x, c1 = 0.25, c2 = 0.75) {
-        -(x - c1) ^ 2 + c2  + rnorm(length(x), 0, 0.01)
-      }
+    arm_function = NULL,
+    initialize   = function(FUN, delta, horizon) {
+      self$arm_function <- FUN
+      self$horizon <- horizon
       self$delta <- delta
-      self$choice <- runif(horizon, min=0, max=1)
-      private$S <- data.frame(self$choice, self$arm_function(self$choice, self$c1, self$c2))
       self$k <- 1
     },
     post_initialization = function() {
+      self$choice <- runif(self$horizon, min=0, max=1)
+      private$S <- data.frame(self$choice, self$arm_function(self$choice))
       private$S <- private$S[sample(nrow(private$S)),]
       colnames(private$S) <- c('choice', 'reward')
-      #print(private$S)
     },
     get_context = function(index) {
       context           <- list()
@@ -37,8 +32,7 @@ OnlineOfflineContinuumBandit <- R6::R6Class(
       reward_at_index <- as.double(private$S$reward[[index]])
       if (abs(private$S$choice[[index]] - action$choice) < self$delta) {
         reward <- list(
-          reward = reward_at_index,
-          optimal_reward = self$c2
+          reward = reward_at_index
         )
       } else {
         NULL
